@@ -220,18 +220,28 @@ def release():
     pass
 
 
-@release.command("create", help="Create a github release")
-@click.option("--deploy", is_flag=True, help="Trigger deploy after release creation")
+@release.command(
+    "create", help="Create a github release (and deploy it if GHA are used)"
+)
+@click.option(
+    "--deploy",
+    is_flag=True,
+    help="Trigger deploy with Drone CI after release creation (Github Actions based microservices will be automatically deployed on production)",
+)
 @click.pass_obj
 def cli_release_create(obj, deploy):
     from suite_py.commands.release import Release
 
     Release(
-        "create", obj["project"], obj["config"], obj["tokens"], flags={"deploy": deploy}
+        "create",
+        obj["project"],
+        obj["config"],
+        obj["tokens"],
+        flags={"deploy": deploy},
     ).run()
 
 
-@release.command("deploy", help="Deploy a github release")
+@release.command("deploy", help="Deploy a github release with Drone CI")
 @click.pass_obj
 def cli_release_deploy(obj):
     from suite_py.commands.release import Release
