@@ -33,18 +33,22 @@ class Release:
         self._repo = self._github.get_repo(project)
         self._git = GitHandler(project, config)
         self._drone = DroneHandler(config, tokens, repo=project)
-        self._countries = _parse_available_countries(self._drone)
         self._version = VersionHandler(self._repo, self._git, self._github)
 
     def run(self):
         self._stop_if_prod_locked()
         self._git.fetch()
 
-        if len(self._countries) == 0:
-            logger.error(
-                "Can't determine which countries can be deployed. Try to run `suite-py deploy` instead."
-            )
-            sys.exit(1)
+        if self._flags:
+            if self._flags.get("deploy", False):
+
+                countries = _parse_available_countries(self._drone)
+
+                if len(countries) == 0:
+                    logger.error(
+                        "Can't determine which countries can be deployed. Try to run `suite-py deploy` instead."
+                    )
+                    sys.exit(1)
 
         if self._action == "create":
             self._create()
@@ -135,19 +139,18 @@ class Release:
             self._deploy(new_version)
 
     def _deploy(self, version=""):
-        if len(self._countries) > 1:
+        countries = _parse_available_countries(self._drone)
+        if len(countries) > 1:
             while True:
                 countries = prompt_utils.ask_multiple_choices(
                     "Which countries do you want to deploy to?",
-                    self._countries,
+                    countries,
                 )
                 if countries:
                     break
                 logger.warning(
                     "You didn't select any country, press SPACEBAR to select countries to deploy to, then press ENTER to confirm!"
                 )
-        else:
-            countries = self._countries
 
         versions = {}
 
@@ -181,9 +184,10 @@ class Release:
         self._manage_youtrack_card(version, countries)
 
     def _rollback(self):
+        countries = _parse_available_countries(self._drone)
         country = prompt_utils.ask_choices(
             "Which country do you want to rollback?",
-            self._countries,
+            countries,
         )
 
         if not country:
@@ -232,7 +236,7 @@ class Release:
             if not builds:
                 # may end up here if there isn't any successfull build for latest 10 tags
                 logger.error(
-                    "An error has occured retrieving current version during rollback.\nPlease ask #team-devops for help."
+                    "An error has occured retrieving current version during rollback.\nPlease ask #team-platform-operations for help."
                 )
                 sys.exit(255)
 
@@ -251,7 +255,7 @@ class Release:
             return v
         except Exception:
             logger.error(
-                "An error has occured retrieving current version during rollback.\nPlease ask #team-devops for help."
+                "An error has occured retrieving current version during rollback.\nPlease ask #team-platform-operations for help."
             )
             sys.exit(255)
 
